dddmp package abstract

`DddmpBddReadHeaderCnf()`
  Reads a the header of a dump file representing the argument BDDs.
`DddmpBddReadHeader()`
  Reads a the header of a dump file representing the argument BDDs.
`DddmpClearVisitedAdd()`
  Marks a node as not visited
`DddmpClearVisitedBdd()`
  Marks a node as not visited
`DddmpClearVisitedCnfRecur()`
  Mark ALL nodes as not visited
`DddmpClearVisitedCnfRecur()`
  Mark ALL nodes as not visited
`DddmpClearVisitedCnf()`
  Marks a node as not visited
`DddmpClearVisitedCnf()`
  Marks a node as not visited
`DddmpClearVisited()`
  Marks a node as not visited
`DddmpCnfClauses2Bdd()`
  Transforms CNF clauses into BDDs.
`DddmpCuddBddArrayStoreCnf()`
  Writes a dump file representing the argument Array of BDDs in the CNF standard format.
`DddmpCuddBddArrayStore()`
  Writes a dump file representing the argument Array of BDDs.
`DddmpCuddDdArrayLoadCnf()`
  Reads a dump file representing the argument BDDs in CNF format.
`DddmpCuddDdArrayLoad()`
  Reads a dump file representing the argument BDDs.
`DddmpCuddDdArrayStoreBdd()`
  Writes a dump file representing the argument Array of BDDs/ADDs.
`DddmpCuddDdArrayStoreBlifBody()`
  Writes a blif body representing the argument BDDs.
`DddmpCuddDdArrayStoreBlifStep()`
  Performs the recursive step of DddmpCuddDdArrayStoreBlif.
`DddmpCuddDdArrayStoreBlif()`
  Writes a blif file representing the argument BDDs.
`DddmpCuddDdArrayStorePrefixBody()`
  Internal function to writes a dump file representing the argument BDD in a prefix notation. Writes the body of the file.
`DddmpCuddDdArrayStorePrefixStep()`
  Performs the recursive step of DddmpCuddDdArrayStorePrefixBody.
`DddmpCuddDdArrayStorePrefix()`
  Internal function to writes a dump file representing the argument BDD in a prefix notation.
`DddmpCuddDdArrayStoreSmvBody()`
  Internal function to writes a dump file representing the argument BDD in a SMV notation. Writes the body of the file.
`DddmpCuddDdArrayStoreSmvStep()`
  Performs the recursive step of DddmpCuddDdArrayStoreSmvBody.
`DddmpCuddDdArrayStoreSmv()`
  Internal function to writes a dump file representing the argument BDD in a SMV notation.
`DddmpDdNodesCheckIncomingAndScanPath()`
  Number nodes recursively in post-order
`DddmpDdNodesCheckIncomingAndScanPath()`
  Number nodes recursively in post-order
`DddmpDdNodesCountEdgesAndNumber()`
  Removes nodes from unique table and numbers each node according to the number of its incoming BDD edges.
`DddmpDdNodesCountEdgesAndNumber()`
  Removes nodes from unique table and numbers each node according to the number of its incoming BDD edges.
`DddmpDdNodesCountEdgesRecur()`
  Counts the number of incoming edges for each node of a BDD
`DddmpDdNodesCountEdgesRecur()`
  Counts the number of incoming edges for each node of a BDD
`DddmpDdNodesNumberEdgesRecur()`
  Number nodes recursively in post-order
`DddmpDdNodesNumberEdgesRecur()`
  Number nodes recursively in post-order
`DddmpDdNodesResetCountRecur()`
  Resets counter and visited flag for ALL nodes of a BDD
`DddmpDdNodesResetCountRecur()`
  Resets counter and visited flag for ALL nodes of a BDD
`DddmpFreeHeaderCnf()`
  Frees the internal header structure.
`DddmpFreeHeader()`
  Frees the internal header structure.
`DddmpIntArrayDup()`
  Duplicates an array of ints
`DddmpIntArrayRead()`
  Inputs an array of ints
`DddmpIntArrayWrite()`
  Outputs an array of ints
`DddmpNumberAddNodes()`
  Removes nodes from unique table and number them
`DddmpNumberBddNodes()`
  Removes nodes from unique table and number them
`DddmpNumberDdNodesCnf()`
  Removes nodes from unique table and numbers them
`DddmpNumberDdNodesCnf()`
  Removes nodes from unique table and numbers them
`DddmpNumberDdNodes()`
  Removes nodes from unique table and number them
`DddmpPrintBddAndNextRecur()`
  Prints debug info
`DddmpPrintBddAndNextRecur()`
  Prints debug info
`DddmpPrintBddAndNext()`
  Prints debug information
`DddmpPrintBddAndNext()`
  Prints debug information
`DddmpReadCnfClauses()`
  Read the CNF clauses from the file in the standard DIMACS format.
`DddmpReadCode()`
  Reads a 1 byte node code
`DddmpReadInt()`
  Reads a "packed integer"
`DddmpReadNodeIndexAdd()`
  Reads the index of a node
`DddmpReadNodeIndexBdd()`
  Reads the index of a node
`DddmpReadNodeIndexCnf()`
  Reads the index of a node
`DddmpReadNodeIndexCnf()`
  Reads the index of a node
`DddmpReadNodeIndex()`
  Reads the index of a node
`DddmpSetVisitedAdd()`
  Marks a node as visited
`DddmpSetVisitedBdd()`
  Marks a node as visited
`DddmpSetVisitedCnf()`
  Marks a node as visited
`DddmpSetVisitedCnf()`
  Marks a node as visited
`DddmpSetVisited()`
  Marks a node as visited
`DddmpStrArrayDup()`
  Duplicates an array of strings
`DddmpStrArrayFree()`
  Frees an array of strings
`DddmpStrArrayRead()`
  Inputs an array of strings
`DddmpStrArrayWrite()`
  Outputs an array of strings
`DddmpStrDup()`
  Duplicates a string
`DddmpUnnumberAddNodes()`
  Restores nodes in unique table, loosing numbering
`DddmpUnnumberBddNodes()`
  Restores nodes in unique table, loosing numbering
`DddmpUnnumberDdNodesCnf()`
  Restores nodes in unique table, loosing numbering
`DddmpUnnumberDdNodesCnf()`
  Restores nodes in unique table, loosing numbering
`DddmpUnnumberDdNodes()`
  Restores nodes in unique table, loosing numbering
`DddmpVisitedAdd()`
  Returns true if node is visited
`DddmpVisitedBdd()`
  Returns true if node is visited
`DddmpVisitedCnf()`
  Returns true if node is visited
`DddmpVisitedCnf()`
  Returns true if node is visited
`DddmpVisited()`
  Returns true if node is visited
`DddmpWriteCode()`
  Writes 1 byte node code
`DddmpWriteInt()`
  Writes a "packed integer"
`DddmpWriteNodeIndexAdd()`
  Write index to node
`DddmpWriteNodeIndexBdd()`
  Write index to node
`DddmpWriteNodeIndexCnfBis()`
  Write index to node
`DddmpWriteNodeIndexCnfWithTerminalCheck()`
  Write index to node
`DddmpWriteNodeIndexCnf()`
  Write index to node
`DddmpWriteNodeIndexCnf()`
  Write index to node
`DddmpWriteNodeIndex()`
  Write index to node
`Dddmp_Bin2Text()`
  Converts from binary to ASCII format
`Dddmp_Text2Bin()`
  Converts from ASCII to binary format
`Dddmp_cuddAddArrayLoad()`
  Reads a dump file representing the argument ADDs.
`Dddmp_cuddAddArrayStore()`
  Writes a dump file representing the argument Array of ADDs.
`Dddmp_cuddAddLoad()`
  Reads a dump file representing the argument ADD.
`Dddmp_cuddAddStore()`
  Writes a dump file representing the argument ADD.
`Dddmp_cuddBddArrayLoadCnf()`
  Reads a dump file in a CNF format.
`Dddmp_cuddBddArrayLoad()`
  Reads a dump file representing the argument BDDs.
`Dddmp_cuddBddArrayStoreBlif()`
  Writes a dump file representing the argument BDD in a Blif/Exlif notation.
`Dddmp_cuddBddArrayStoreCnf()`
  Writes a dump file representing the argument array of BDDs in CNF format.
`Dddmp_cuddBddArrayStorePrefix()`
  Writes a dump file representing the argument BDD in a prefix notation.
`Dddmp_cuddBddArrayStoreSmv()`
  Writes a dump file representing the argument BDD in a prefix notation.
`Dddmp_cuddBddArrayStore()`
  Writes a dump file representing the argument Array of BDDs.
`Dddmp_cuddBddDisplayBinary()`
  Display a binary dump file in a text file
`Dddmp_cuddBddLoadCnf()`
  Reads a dump file in a CNF format.
`Dddmp_cuddBddLoad()`
  Reads a dump file representing the argument BDD.
`Dddmp_cuddBddStoreBlif()`
  Writes a dump file representing the argument BDD in a Blif/Exlif notation.
`Dddmp_cuddBddStoreCnf()`
  Writes a dump file representing the argument BDD in a CNF format.
`Dddmp_cuddBddStorePrefix()`
  Writes a dump file representing the argument BDD in a prefix notation.
`Dddmp_cuddBddStoreSmv()`
  Writes a dump file representing the argument BDD in a prefix notation.
`Dddmp_cuddBddStore()`
  Writes a dump file representing the argument BDD.
`Dddmp_cuddHeaderLoadCnf()`
  Reads the header of a dump file representing the argument BDDs
`Dddmp_cuddHeaderLoad()`
  Reads the header of a dump file representing the argument BDDs
`FindVarname()`
  Performs binary search of a name within a sorted array
`NodeBinaryStoreBdd()`
  Store One Single Node in Binary Format.
`NodeStoreRecurAdd()`
  Performs the recursive step of Dddmp_bddStore.
`NodeStoreRecurBdd()`
  Performs the recursive step of Dddmp_bddStore.
`NodeTextStoreAdd()`
  Store One Single Node in Text Format.
`NodeTextStoreBdd()`
  Store One Single Node in Text Format.
`NumberNodeRecurAdd()`
  Number nodes recursively in post-order
`NumberNodeRecurBdd()`
  Number nodes recursively in post-order
`NumberNodeRecurCnf()`
  Number nodes recursively in post-order
`NumberNodeRecurCnf()`
  Number nodes recursively in post-order
`NumberNodeRecur()`
  Number nodes recursively in post-order
`QsortStrcmp()`
  String compare for qsort
`ReadByteBinary()`
  Reads a byte from file with escaped , and
`RemoveFromUniqueRecurAdd()`
  Removes a node from unique table
`RemoveFromUniqueRecurBdd()`
  Removes a node from unique table
`RemoveFromUniqueRecurCnf()`
  Removes a node from unique table
`RemoveFromUniqueRecurCnf()`
  Removes a node from unique table
`RemoveFromUniqueRecur()`
  Removes a node from unique table
`RestoreInUniqueRecurAdd()`
  Restores a node in unique table
`RestoreInUniqueRecurBdd()`
  Restores a node in unique table
`RestoreInUniqueRecurCnf()`
  Restores a node in unique table
`RestoreInUniqueRecurCnf()`
  Restores a node in unique table
`RestoreInUniqueRecur()`
  Restores a node in unique table
`StoreCnfBestNotSharedRecur()`
  Performs the recursive step of Print Best on Not Shared sub-BDDs.
`StoreCnfBestSharedRecur()`
  Performs the recursive step of Print Best on Shared sub-BDDs.
`StoreCnfBest()`
  Prints a disjoint sum of products with intermediate cutting points.
`StoreCnfMaxtermByMaxtermRecur()`
  Performs the recursive step of Print Maxterm.
`StoreCnfMaxtermByMaxterm()`
  Prints a disjoint sum of products.
`StoreCnfNodeByNodeRecur()`
  Performs the recursive step of Dddmp_bddStore.
`StoreCnfNodeByNode()`
  Store the BDD as CNF clauses.
`StoreCnfOneNode()`
  Store One Single BDD Node.
`WriteByteBinary()`
  Writes a byte to file filtering , and
`printCubeCnf()`
  Print One Cube in CNF Format.
`()`
  Checks for Warnings: If expr==1 it prints out the warning on stderr.
`()`
  Checks for fatal bugs
`()`
  Checks for fatal bugs and go to the label to deal with the error.
`()`
  Checks for fatal bugs and return the DDDMP_FAILURE flag.
`()`
  Memory Allocation Macro for DDDMP
`()`
  Memory Free Macro for DDDMP

Last updated on 1040218 17h14